==> 0.9.0+20151028.tar.gz: lxqt-notificationd-packaging/config/translations/lxqt-config-notificationd_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Расстояние:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="74"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Некоторые уведомления сами устанавливают свою длительность на экране.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="86"/>
        <source>Default duration:</source>
        <translation>Длительность по умолчанию:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="93"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Расположение на экране</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="36"/>
        <source>Top/Left</source>
        <translation>Вверху слева</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="43"/>
        <source>Top/Right</source>
        <translation>Вверху справа</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="50"/>
        <source>Bottom/Left</source>
        <translation>Внизу слева</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="57"/>
        <source>Bottom/Right</source>
        <translation>Внизу справа</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="53"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений не запущен.
Будет использован резервный вариант.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="59"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений третьей сторон (%1) запущен.
Эти настройки не будут иметь никакого эффекта для него!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="98"/>
        <source>Notification demo</source>
        <translation>Демонстрация уведомления</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="99"/>
        <source>This is a test notification.
All notifications will now appear here on LXQt.</source>
        <translation>Это тестовое уведомление.
Все уведомления на LXQt будут появляться здесь.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Системные уведомления</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Расширенные настройки</translation>
    </message>
</context>
</TS>

==> 0.10.0.tar.gz: lxqt-notificationd-packaging/config/translations/lxqt-config-notificationd_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Расстояние:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Некоторые уведомления сами устанавливают свою длительность на экране.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Длительность по умолчанию:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Расположение на экране</translation>
    </message>
    <message>
        <source>Top/Left</source>
        <translation type="vanished">Вверху слева</translation>
    </message>
    <message>
        <source>Top/Right</source>
        <translation type="vanished">Вверху справа</translation>
    </message>
    <message>
        <source>Bottom/Left</source>
        <translation type="vanished">Внизу слева</translation>
    </message>
    <message>
        <source>Bottom/Right</source>
        <translation type="vanished">Внизу справа</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений не запущен.
Будет использован резервный вариант.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений третьей сторон (%1) запущен.
Эти настройки не будут иметь никакого эффекта для него!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification demo</source>
        <translation type="vanished">Демонстрация уведомления</translation>
    </message>
    <message>
        <source>This is a test notification.
All notifications will now appear here on LXQt.</source>
        <translation type="vanished">Это тестовое уведомление.
Все уведомления на LXQt будут появляться здесь.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Системные уведомления</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Расширенные настройки</translation>
    </message>
</context>
</TS>
